==> haskell-persistent-test-2.13.1.3-128-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-6qdnq4ox6Er9KDXEandFvn
key:                  persistent-test-2.13.1.3-6qdnq4ox6Er9KDXEandFvn
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  4c2b03622fc25754e88f850ca50a6771
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-6qdnq4ox6Er9KDXEandFvn
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    QuickCheck-2.14.3-2QKb6Hom0yuuAm9FvZ6nN
    aeson-2.1.2.1-2ooOAwlErgbHj6Tyvuh2I5 base-4.17.2.1
    blaze-html-0.9.2.0-IKVhdom3eJ46byuPgdmCPo bytestring-0.11.5.3
    conduit-1.3.6.1-IWWL48tOiUMKLUHQSWumck containers-0.6.7
    exceptions-0.10.5 hspec-2.10.10-4hshClf7m0IIR9RVkS3XPo
    hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568
    http-api-data-0.5.1-9BGm2iLcXIXKS2o0PEBMUu
    monad-control-1.0.3.1-ADBy113jPZx6EyMvvTxyI9
    monad-logger-0.3.42-8YzD6ma2kxN4VUsQwT923R mtl-2.2.2
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    persistent-2.14.5.1-6fvLVFPOi4V4q3VR5hpP5X
    quickcheck-instances-0.3.30-1kV47Ymxv0DEHQAgPTxRqj
    random-1.2.1.3-K04qxPoOyGIAJkhpqYiZaH
    resourcet-1.2.6-3PSKFpTI3ZgIKasExv0vYD text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-5fKXdbxww34Jppu8NGc4jg
    unliftio-0.2.25.1-GCWK91PtajeLr5gMmt0DWz
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-5aRSzj1YCHv4h2N6lFa6Hx

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-test-2.13.1.3-130-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-Anhk5r1ypuXDWXMV17tzHE
key:                  persistent-test-2.13.1.3-Anhk5r1ypuXDWXMV17tzHE
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  c6c41cf62d5139713901ad6f241bbcf6
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-Anhk5r1ypuXDWXMV17tzHE
depends:
    HUnit-1.6.2.0-JlkHGrwnzdW73OrIAc87UZ
    QuickCheck-2.14.3-7hqZHxjEzJA3sWW6zgGwOZ
    aeson-2.1.2.1-HPwo2VO3hzcFr4fiGB5Oro base-4.17.2.1
    blaze-html-0.9.2.0-HIsrFdX7DIkeeC0HU7u92 bytestring-0.11.5.3
    conduit-1.3.6.1-CuuvisR1uAaJsPmK0tVtaN containers-0.6.7
    exceptions-0.10.5 hspec-2.10.10-ELmZqpmmMLvY6tR5yEZxU
    hspec-expectations-0.8.3-CkvzPqJylGGF3abH5hNhDB
    http-api-data-0.5.1-FzufEX8MEsi9btyhAtyND7
    monad-control-1.0.3.1-C2PqGHhdKhuEnXRqrlVLv
    monad-logger-0.3.42-JSO33w1Uk252WCM5meOxN5 mtl-2.2.2
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    persistent-2.14.5.1-JTp12zNUtiI2P5lUljZqfl
    quickcheck-instances-0.3.30-K8wE0Bwjgq9pgWZgk8lle
    random-1.2.1.3-8vZ5nHC8xeMEF0rmgzNDZj
    resourcet-1.2.6-7D9C6Av1VFDBpMT9JTpoCU text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-BsvRNJkvHKF3eWbBhwGoLx
    unliftio-0.2.25.1-DYznH1vHiFW9UOG5RP6OX5
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-FFF0GulGLFtAHq6N1Lkm0s

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
